.category-image, .category-label {
    padding: 3pt;
}

Gjs_MenuPopover {
    padding: 0;
}

Gjs_MenuPopover GtkScrolledWindow {
    border-width: 1px 0;
}

Gjs_MenuPopover .list-row {
    padding: 5px 6px;
}

.banner {
    color: @insensitive_fg_color;
}

.banner-label {
    padding: 10pt;
    font-size: x-large;
}

.character-list {
    color: rgb(0, 0, 0);
    background-color: rgb(255, 255, 255);
}

.character-label {
    font-size: 7em;
    font-weight: bold;
}

.detail-label {
    font-size: small;
}

.related .character {
    font-size: 3em;
}

.related .list-row {
    border-style: groove;
    border-width: 2pt;
}

@binding-set ScrollUnmodified {
  bind "space" { "scroll-child" (page-down, 0) };
  bind "Up" { "scroll-child" (step-up, 0) };
  bind "Down" { "scroll-child" (step-down, 0) };
}

GtkScrolledWindow.character-list-scroll {
  gtk-key-bindings: ScrollUnmodified;
}
