/* DO NOT EDIT! GENERATED AUTOMATICALLY! */
/* Properties of Unicode characters.  */
/* Generated automatically by gen-uni-tables.c for Unicode 8.0.0.  */
#define header_0 16
#define header_2 9
#define header_3 127
#define header_4 15
static const
struct
  {
    int header[1];
    int level1[17];
    short level2[2 << 7];
    /*unsigned*/ int level3[3 << 4];
  }
u_property_private_use =
{
  { 17 },
  {
       18 * sizeof (int) / sizeof (short) +     0,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       18 * sizeof (int) / sizeof (short) +   128,
       18 * sizeof (int) / sizeof (short) +   128
  },
  {
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +    16,
       -1,
       -1,
       -1,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +     0,
       18 +   256 * sizeof (short) / sizeof (int) +    32
  },
  {
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x3FFFFFFF
  }
};
