/* DO NOT EDIT! GENERATED AUTOMATICALLY! */
/* Properties of Unicode characters.  */
/* Generated automatically by gen-uni-tables.c for Unicode 8.0.0.  */
#define header_0 16
#define header_2 9
#define header_3 127
#define header_4 15
static const
struct
  {
    int header[1];
    int level1[15];
    short level2[4 << 7];
    /*unsigned*/ int level3[65 << 4];
  }
u_property_id_continue =
{
  { 15 },
  {
       16 * sizeof (int) / sizeof (short) +     0,
       16 * sizeof (int) / sizeof (short) +   128,
       16 * sizeof (int) / sizeof (short) +   256,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 * sizeof (int) / sizeof (short) +   384
  },
  {
       16 +   512 * sizeof (short) / sizeof (int) +     0,
       16 +   512 * sizeof (short) / sizeof (int) +    16,
       16 +   512 * sizeof (short) / sizeof (int) +    32,
       16 +   512 * sizeof (short) / sizeof (int) +    48,
       16 +   512 * sizeof (short) / sizeof (int) +    64,
       16 +   512 * sizeof (short) / sizeof (int) +    80,
       16 +   512 * sizeof (short) / sizeof (int) +    96,
       16 +   512 * sizeof (short) / sizeof (int) +   112,
       16 +   512 * sizeof (short) / sizeof (int) +   128,
       16 +   512 * sizeof (short) / sizeof (int) +   144,
       16 +   512 * sizeof (short) / sizeof (int) +   160,
       16 +   512 * sizeof (short) / sizeof (int) +   176,
       16 +   512 * sizeof (short) / sizeof (int) +   192,
       16 +   512 * sizeof (short) / sizeof (int) +   208,
       16 +   512 * sizeof (short) / sizeof (int) +   224,
       16 +   512 * sizeof (short) / sizeof (int) +   240,
       16 +   512 * sizeof (short) / sizeof (int) +   256,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   272,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   288,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   320,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   336,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   352,
       16 +   512 * sizeof (short) / sizeof (int) +   368,
       16 +   512 * sizeof (short) / sizeof (int) +   384,
       16 +   512 * sizeof (short) / sizeof (int) +   400,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   416,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   432,
       16 +   512 * sizeof (short) / sizeof (int) +   448,
       16 +   512 * sizeof (short) / sizeof (int) +   464,
       16 +   512 * sizeof (short) / sizeof (int) +   480,
       16 +   512 * sizeof (short) / sizeof (int) +   496,
       16 +   512 * sizeof (short) / sizeof (int) +   512,
       16 +   512 * sizeof (short) / sizeof (int) +   528,
       16 +   512 * sizeof (short) / sizeof (int) +   544,
       16 +   512 * sizeof (short) / sizeof (int) +   560,
       16 +   512 * sizeof (short) / sizeof (int) +   576,
       16 +   512 * sizeof (short) / sizeof (int) +   592,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   608,
       16 +   512 * sizeof (short) / sizeof (int) +   624,
       16 +   512 * sizeof (short) / sizeof (int) +   640,
       16 +   512 * sizeof (short) / sizeof (int) +   656,
       16 +   512 * sizeof (short) / sizeof (int) +   672,
       16 +   512 * sizeof (short) / sizeof (int) +   688,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   704,
       16 +   512 * sizeof (short) / sizeof (int) +   720,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   736,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   752,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   768,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   784,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   800,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   816,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   832,
       16 +   512 * sizeof (short) / sizeof (int) +   848,
       16 +   512 * sizeof (short) / sizeof (int) +   864,
       16 +   512 * sizeof (short) / sizeof (int) +   880,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   896,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   912,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   928,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   944,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   960,
       16 +   512 * sizeof (short) / sizeof (int) +   976,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +   992,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +   304,
       16 +   512 * sizeof (short) / sizeof (int) +  1008,
       -1,
       -1,
       16 +   512 * sizeof (short) / sizeof (int) +  1024,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1
  },
  {
    0x00000000, 0x03FF0000, 0x87FFFFFE, 0x07FFFFFE,
    0x00000000, 0x04A00400, 0xFF7FFFFF, 0xFF7FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x0003FFC3, 0x0000501F,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xBCDFFFFF,
    0xFFFFD7C0, 0xFFFFFFFB, 0xFFFFFFFF, 0xFFBFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFCFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFEFFFF, 0x027FFFFF, 0xFFFFFFFE,
    0xFFFE00FF, 0xBFFFFFFF, 0xFFFF00B6, 0x000707FF,
    0x07FF0000, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFC3FF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x9FEFFFFF, 0x9FFFFDFF,
    0xFFFF0000, 0xFFFFFFFF, 0xFFFFE7FF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x0003FFFF, 0xFFFFFFFF, 0x043FFFFF,
    0xFFFFFFFF, 0x00003FFF, 0x0FFFFFFF, 0x00000000,
    0x00000000, 0x001FFFFF, 0x00000000, 0xFFFFFFF8,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFEFFCF,
    0xFFF99FEF, 0xF3C5FDFF, 0xB080799F, 0x0003FFCF,
    0xFFF987EE, 0xD36DFDFF, 0x5E023987, 0x003FFFC0,
    0xFFFBBFEE, 0xF3EDFDFF, 0x00013BBF, 0x0200FFCF,
    0xFFF99FEE, 0xF3EDFDFF, 0xB0C0399F, 0x0002FFCF,
    0xD63DC7EC, 0xC3FFC718, 0x00813DC7, 0x0000FFC0,
    0xFFFDDFEF, 0xE3FFFDFF, 0x07603DDF, 0x0000FFCF,
    0xFFFDDFEE, 0xF3EFFDFF, 0x40603DDF, 0x0006FFCF,
    0xFFFDDFEE, 0xE7FFFFFF, 0x80807DDF, 0xFC00FFCF,
    0xFC7FFFEC, 0x2FFBFFFF, 0xFF5F847F, 0x000CFFC0,
    0xFFFFFFFE, 0x07FFFFFF, 0x03FF7FFF, 0x00000000,
    0xFEF02596, 0x3BFFECAE, 0xF3FF3F5F, 0x00000000,
    0x03000001, 0xC2A003FF, 0xFFFFFEFF, 0xFFFE1FFF,
    0xFEFFFFDF, 0x1FFFFFFF, 0x00000040, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFF03FF, 0xFFFFFFFF,
    0x3FFFFFFF, 0xFFFFFFFF, 0xFFFF20BF, 0xF7FFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x3D7F3DFF, 0xFFFFFFFF,
    0xFFFF3DFF, 0x7F3DFFFF, 0xFF7FFF3D, 0xFFFFFFFF,
    0xFF3DFFFF, 0xFFFFFFFF, 0xE7FFFFFF, 0x0003FE00,
    0x0000FFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x3F3FFFFF,
    0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFF9FFF,
    0x07FFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0x01FFC7FF,
    0x001FDFFF, 0x001FFFFF, 0x000FFFFF, 0x000DDFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x308FFFFF, 0x000003FF,
    0x03FF3800, 0xFFFFFFFF, 0xFFFFFFFF, 0x00FFFFFF,
    0xFFFFFFFF, 0xFFFF07FF, 0xFFFFFFFF, 0x003FFFFF,
    0x7FFFFFFF, 0x0FFF0FFF, 0xFFFFFFC0, 0x001F3FFF,
    0xFFFFFFFF, 0xFFFF0FFF, 0x07FF03FF, 0x00000000,
    0x0FFFFFFF, 0xFFFFFFFF, 0x7FFFFFFF, 0x9FFFFFFF,
    0x03FF03FF, 0x3FFF0080, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0x03FF0FFF, 0x000FF800,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000FFFFF,
    0xFFFFFFFF, 0x00FFFFFF, 0xFFFFE3FF, 0x3FFFFFFF,
    0x00000000, 0x00000000, 0xFFF70000, 0x037FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xF03FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x3F3FFFFF, 0xFFFFFFFF, 0xAAFF3F3F, 0x3FFFFFFF,
    0xFFFFFFFF, 0x5FDFFFFF, 0x0FCF1FDC, 0x1FDC1FFF,
    0x00000000, 0x80000000, 0x00100001, 0x80020000,
    0x1FFF0000, 0x00000000, 0x1FFF0000, 0x0001FFE2,
    0x3F2FFC84, 0xF3FFFD50, 0x000043E0, 0xFFFFFFFF,
    0x000001FF, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFF7FFF, 0x7FFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000FF81F,
    0xFFFFFFFF, 0xFFFF20BF, 0xFFFFFFFF, 0x800080FF,
    0x007FFFFF, 0x7F7F7F7F, 0x7F7F7F7F, 0xFFFFFFFF,
    0x000000E0, 0x1F3EFFFE, 0xFFFFFFFE, 0xFFFFFFFF,
    0xFE7FFFFF, 0xFFFFFFFE, 0xFFFFFFFF, 0xF7FFFFFF,
    0xFFFFFFE0, 0xFFFE3FFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00007FFF, 0x07FFFFFF, 0x00000000, 0xFFFF0000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x003FFFFF, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x003FFFFF, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00001FFF, 0x00000000, 0xFFFF0000, 0x3FFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFF1FFF, 0x00000FFF, 0xFFFFFFFF, 0xBFF0FFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0003FFFF,
    0xFF800000, 0xFFFFFFFC, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFF9FF, 0x00FF3FFF, 0x00000000, 0xFF800000,
    0xFFFFFFFF, 0x000000FF, 0xFFFFFFFF, 0x000FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x03FF001F, 0x28FFFFFF,
    0xFFFFFFFF, 0xFFFF3FFF, 0x000FFFFF, 0x1FFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x03FF8001, 0x7FFFFFFF,
    0xFFFFFFFF, 0x007FFFFF, 0x03FF3FFF, 0xFC7FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x38000007, 0x007CFFFF,
    0x007E7E7E, 0xFFFF7F7F, 0xF7FFFFFF, 0xFFFF003F,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x03FF37FF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFF000F, 0xFFFFF87F, 0x0FFFFFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFF3FFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x03FFFFFF, 0x00000000,
    0xE0F8007F, 0x5F7FFDFF, 0xFFFFFFDB, 0xFFFFFFFF,
    0xFFFFFFFF, 0x0003FFFF, 0xFFF80000, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x3FFFFFFF, 0xFFFF0000, 0xFFFFFFFF,
    0xFFFCFFFF, 0xFFFFFFFF, 0x000000FF, 0x0FFF0000,
    0x0000FFFF, 0x0018FFFF, 0x0000E000, 0xFFDF0000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x1FFFFFFF,
    0x03FF0000, 0x87FFFFFE, 0x07FFFFFE, 0xFFFFFFC0,
    0xFFFFFFFF, 0x7FFFFFFF, 0x1CFCFCFC, 0x00000000,
    0xFFFFEFFF, 0xB7FFFF7F, 0x3FFF3FFF, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x07FFFFFF,
    0x00000000, 0x00000000, 0xFFFFFFFF, 0x001FFFFF,
    0x00000000, 0x00000000, 0x00000000, 0x20000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x1FFFFFFF, 0xFFFFFFFF, 0x0001FFFF, 0x00000001,
    0xFFFFFFFF, 0xFFFF0000, 0xFFFF07FF, 0x07FFFFFF,
    0x3FFFFFFF, 0xFFFFFFFF, 0x003EFF0F, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x3FFFFFFF, 0x000003FF, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFF00FF, 0xFFFFFFFF, 0x0000000F,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x007FFFFF, 0x003FFFFF, 0x000000FF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFD3F, 0x91BFFFFF, 0x003FFFFF, 0x007FFFFF,
    0x7FFFFFFF, 0x00000000, 0x00000000, 0x0037FFFF,
    0x003FFFFF, 0x03FFFFFF, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xC0FFFFFF, 0x00000000, 0x00000000,
    0xFEEFF06F, 0x870FFFFF, 0x00000000, 0x1FFFFFFF,
    0x1FFFFFFF, 0x00000000, 0xFFFFFEFF, 0x0000007F,
    0xFFFFFFFF, 0x003FFFFF, 0x003FFFFF, 0x0007FFFF,
    0x0003FFFF, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0x000001FF, 0x00000000,
    0xFFFFFFFF, 0x0007FFFF, 0xFFFFFFFF, 0x0007FFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0x0000007F, 0x8000FFC0,
    0xFFFFFFFF, 0x07FFFFFF, 0xFFFF0000, 0x03FF01FF,
    0xFFFFFFFF, 0xFFDFFFFF, 0xFFFF0000, 0x004FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x17FF1C1F, 0x00000000,
    0xFFFBFFFF, 0x00FFFFFF, 0x00000000, 0x00000000,
    0xBFFFBD7F, 0xFFFF01FF, 0xFFFFFFFF, 0x03FF07FF,
    0xFFF99FEF, 0xF3EDFDFF, 0xE081399F, 0x001F1FCF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0x03FF00BF, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFF3FFFFF, 0x3F000001, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0x03FF0011, 0x00000000,
    0xFFFFFFFF, 0x00FFFFFF, 0x000003FF, 0x00000000,
    0xE3FFFFFF, 0x03FF0FFF, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0xFFFFFFFF, 0xFFFFFFFF, 0x800003FF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0xFFFFFFFF, 0x01FFFFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x03FFFFFF, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00007FFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x0000000F, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0x00007FFF, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0x0000007F, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0x01FFFFFF, 0x7FFFFFFF, 0x000003FF,
    0x00000000, 0x00000000, 0xFFFF0000, 0x001F3FFF,
    0xFFFFFFFF, 0x007FFFFF, 0x03FF000F, 0xE0FFFFF8,
    0x0000FFFF, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFF001F, 0x7FFFFFFF,
    0xFFFF8000, 0x00000000, 0x00000000, 0x00000000,
    0x00000003, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x1FFF07FF,
    0x63FF01FF, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0xF807E3E0,
    0x00000FE7, 0x00003C00, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x0000001C, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFDFFFFF, 0xFFFFFFFF,
    0xDFFFFFFF, 0xEBFFDE64, 0xFFFFFFEF, 0xFFFFFFFF,
    0xDFDFE7BF, 0x7BFFFFFF, 0xFFFDFC5F, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFF3F, 0xF7FFFFFD, 0xF7FFFFFF,
    0xFFDFFFFF, 0xFFDFFFFF, 0xFFFF7FFF, 0xFFFF7FFF,
    0xFFFFFDFF, 0xFFFFFDFF, 0xFFFFCFF7, 0xFFFFFFFF,
    0xFFFFFFFF, 0xF87FFFFF, 0xFFFFFFFF, 0x00201FFF,
    0xF8000010, 0x0000FFFE, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x007F001F, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFEF, 0x0AF7FE96, 0xAA96EA84, 0x5EF7F796,
    0x0FFFFBFF, 0x0FFFFBEE, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x007FFFFF, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x001FFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x3FFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x00000003, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x3FFFFFFF, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0000FFFF
  }
};
