/* DO NOT EDIT! GENERATED AUTOMATICALLY! */
/* Properties of Unicode characters.  */
/* Generated automatically by gen-uni-tables.c for Unicode 8.0.0.  */
#define header_0 16
#define header_2 9
#define header_3 127
#define header_4 15
static const
struct
  {
    int header[1];
    int level1[3];
    short level2[3 << 7];
    /*unsigned*/ int level3[74 << 4];
  }
u_property_grapheme_base =
{
  { 3 },
  {
        4 * sizeof (int) / sizeof (short) +     0,
        4 * sizeof (int) / sizeof (short) +   128,
        4 * sizeof (int) / sizeof (short) +   256
  },
  {
        4 +   384 * sizeof (short) / sizeof (int) +     0,
        4 +   384 * sizeof (short) / sizeof (int) +    16,
        4 +   384 * sizeof (short) / sizeof (int) +    32,
        4 +   384 * sizeof (short) / sizeof (int) +    48,
        4 +   384 * sizeof (short) / sizeof (int) +    64,
        4 +   384 * sizeof (short) / sizeof (int) +    80,
        4 +   384 * sizeof (short) / sizeof (int) +    96,
        4 +   384 * sizeof (short) / sizeof (int) +   112,
        4 +   384 * sizeof (short) / sizeof (int) +   128,
        4 +   384 * sizeof (short) / sizeof (int) +   144,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   176,
        4 +   384 * sizeof (short) / sizeof (int) +   192,
        4 +   384 * sizeof (short) / sizeof (int) +   208,
        4 +   384 * sizeof (short) / sizeof (int) +   224,
        4 +   384 * sizeof (short) / sizeof (int) +   240,
        4 +   384 * sizeof (short) / sizeof (int) +   256,
        4 +   384 * sizeof (short) / sizeof (int) +   272,
        4 +   384 * sizeof (short) / sizeof (int) +   288,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   304,
        4 +   384 * sizeof (short) / sizeof (int) +   320,
        4 +   384 * sizeof (short) / sizeof (int) +   336,
        4 +   384 * sizeof (short) / sizeof (int) +   352,
        4 +   384 * sizeof (short) / sizeof (int) +   368,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   384,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   400,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   416,
        4 +   384 * sizeof (short) / sizeof (int) +   432,
        4 +   384 * sizeof (short) / sizeof (int) +   448,
        4 +   384 * sizeof (short) / sizeof (int) +   464,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   480,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   496,
        4 +   384 * sizeof (short) / sizeof (int) +   512,
        4 +   384 * sizeof (short) / sizeof (int) +   528,
        4 +   384 * sizeof (short) / sizeof (int) +   544,
        4 +   384 * sizeof (short) / sizeof (int) +   560,
        4 +   384 * sizeof (short) / sizeof (int) +   576,
        4 +   384 * sizeof (short) / sizeof (int) +   592,
        4 +   384 * sizeof (short) / sizeof (int) +   608,
        4 +   384 * sizeof (short) / sizeof (int) +   624,
        4 +   384 * sizeof (short) / sizeof (int) +   640,
        4 +   384 * sizeof (short) / sizeof (int) +   656,
        4 +   384 * sizeof (short) / sizeof (int) +   672,
        4 +   384 * sizeof (short) / sizeof (int) +   688,
        4 +   384 * sizeof (short) / sizeof (int) +   704,
        4 +   384 * sizeof (short) / sizeof (int) +   720,
        4 +   384 * sizeof (short) / sizeof (int) +   736,
        4 +   384 * sizeof (short) / sizeof (int) +   752,
        4 +   384 * sizeof (short) / sizeof (int) +   768,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   784,
        4 +   384 * sizeof (short) / sizeof (int) +   800,
       -1,
       -1,
       -1,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   816,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   832,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   848,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   864,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   880,
       -1,
       -1,
       -1,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   896,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   912,
        4 +   384 * sizeof (short) / sizeof (int) +   928,
        4 +   384 * sizeof (short) / sizeof (int) +   944,
        4 +   384 * sizeof (short) / sizeof (int) +   960,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   976,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   992,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +  1008,
        4 +   384 * sizeof (short) / sizeof (int) +  1024,
        4 +   384 * sizeof (short) / sizeof (int) +  1040,
        4 +   384 * sizeof (short) / sizeof (int) +  1056,
        4 +   384 * sizeof (short) / sizeof (int) +  1072,
        4 +   384 * sizeof (short) / sizeof (int) +  1088,
       -1,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +  1104,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +  1120,
        4 +   384 * sizeof (short) / sizeof (int) +  1136,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +  1152,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
        4 +   384 * sizeof (short) / sizeof (int) +   160,
        4 +   384 * sizeof (short) / sizeof (int) +  1168,
       -1,
       -1
  },
  {
    0x00000000, 0xFFFFFFFF, 0xFFFFFFFF, 0x7FFFFFFF,
    0x00000000, 0xFFFFDFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00000000, 0x00000000, 0x00000000, 0xFCFF0000,
    0xFFFFD7F0, 0xFFFFFFFB, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFC07, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFEFFFF, 0xFE7FFFFF, 0xFFFFFFFE,
    0x0000E6FF, 0x40000000, 0xFFFF0049, 0x001F07FF,
    0xC800FFC0, 0xFFFFFFFF, 0x000007FF, 0xFFFEFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x403FFFFF, 0xFFFFC260,
    0xFFFD3FFF, 0x0000FFFF, 0xFFFFE000, 0xFFFFFFFF,
    0xFFFFFFFF, 0x0002003F, 0xFFFFFFFF, 0x07F007FF,
    0x043FFFFF, 0x7FFF0110, 0x41FFFFFF, 0x00000000,
    0x00000000, 0x001FFFFF, 0x00000000, 0x00000000,
    0xFFFFFFF8, 0xEBFFFFFF, 0xFF01DE01, 0xFFFFFFF3,
    0xFFF99FED, 0xA3C5FDFF, 0xB0005981, 0x0FFFFFC3,
    0xFFF987E8, 0xC36DFDFF, 0x5E000001, 0x001CFFC0,
    0xFFFBBFE8, 0xE3EDFDFF, 0x00011A01, 0x0203FFC3,
    0xFFF99FEC, 0x23EDFDFF, 0xB0001981, 0x00FFFFC3,
    0xD63DC7E8, 0x83FFC718, 0x00011DC6, 0x07FFFFC0,
    0xFFFDDFEE, 0x23FFFDFF, 0x0700001E, 0xFF00FFC3,
    0xFFFDDFEC, 0x63EFFDFF, 0x40000D9B, 0x0006FFC3,
    0xFFFDDFEC, 0xA7FFFFFF, 0x80005DC1, 0xFE3FFFC3,
    0xFC7FFFEC, 0x2FFBFFFF, 0x7F03007F, 0x001CFFC0,
    0xFFFFFFFE, 0x800DFFFF, 0x0FFF807F, 0x00000000,
    0xFEF02596, 0x200DECAE, 0xF3FF005F, 0x00000000,
    0xFCFFFFFF, 0xFD5FFFFF, 0xFFFFFEFF, 0x80001FFF,
    0x00001F20, 0xC0000000, 0x07FFDFBF, 0x00000000,
    0xFFFFFFFF, 0x99021FFF, 0x3CFFFFFF, 0xFFE1FFFE,
    0xDFFFDF9B, 0xFFFFFFFF, 0xFFFF20BF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x3D7F3DFF, 0xFFFFFFFF,
    0xFFFF3DFF, 0x7F3DFFFF, 0xFF7FFF3D, 0xFFFFFFFF,
    0xFF3DFFFF, 0xFFFFFFFF, 0x07FFFFFF, 0x1FFFFFFF,
    0x03FFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x3F3FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x1FFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x01FFFFFF,
    0x0003DFFF, 0x0063FFFF, 0x0003FFFF, 0x0001DFFF,
    0xFFFFFFFF, 0xC04FFFFF, 0x1FF001BF, 0x03FF03FF,
    0x03FF07FF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00FFFFFF,
    0xFFFFFFFF, 0xFFFF05FF, 0xFFFFFFFF, 0x003FFFFF,
    0x7FFFFFFF, 0x01FB0E78, 0xFFFFFFF1, 0x001F3FFF,
    0xFFFFFFFF, 0xFFFF0FFF, 0xC7FF03FF, 0xFFFFFFFF,
    0xC67FFFFF, 0xFFFFFFFF, 0x00BFFFFF, 0x0007E01A,
    0x03FF03FF, 0x00003FFF, 0x00000000, 0x00000000,
    0xFFFFFFF0, 0xE82FFFFF, 0xFFFF0FFB, 0x1FF007FF,
    0xFFFFFFFC, 0xFFFFC4C3, 0xFFFFFFFF, 0xF00C5CBF,
    0xFFFFFFFF, 0xF8300FFF, 0xFFFFE3FF, 0xFFFFFFFF,
    0x00000000, 0x00000000, 0x000800FF, 0x006FDE02,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x3F3FFFFF, 0xFFFFFFFF, 0xAAFF3F3F, 0x3FFFFFFF,
    0xFFFFFFFF, 0xFFDFFFFF, 0xEFCFFFDF, 0x7FDCFFFF,
    0xFFFF07FF, 0xFFFF80FF, 0xFFFFFFFF, 0xFFF30000,
    0x1FFF7FFF, 0x7FFFFFFF, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFF0FFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x07FFFFFF,
    0xFFFFFFFF, 0x0000007F, 0x000007FF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFCFFFFF,
    0xFF3FFFFF, 0xE3FFFFFF, 0x0003FDFF, 0x0000F000,
    0xFFFFFFFF, 0xFFFF7FFF, 0x7FFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFE0C7FFF,
    0xFFFFFFFF, 0xFFFF20BF, 0xFFFFFFFF, 0x000180FF,
    0x007FFFFF, 0x7F7F7F7F, 0x7F7F7F7F, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0x00000007, 0x00000000,
    0xFBFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x003FFFFF, 0x0FFF0000,
    0xFFFFFFFF, 0xFFFF03FF, 0xFFFFFFFE, 0xFFFFFFFF,
    0xF87FFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFE0, 0xFFFE3FFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFF7FFF, 0x07FFFFFF, 0xFFFFFFFF, 0xFFFF000F,
    0x7FFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x7FFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x003FFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x003FFFFF, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFF1FFF, 0xFFFFFFFF, 0xFFFF007F, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x00000FFF, 0xFFFFFFFF, 0xC0087FFF,
    0x3FFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00FCFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x00FF3FFF, 0x00000000, 0xFF800000,
    0xFFFFF7BB, 0x03FF0F9F, 0xFFFFFFFF, 0x00FFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x03FFC00F, 0x3FFC0000,
    0xFFFFFFFF, 0xFFFFC03F, 0x800C007F, 0x1FFFFFFF,
    0xFFFFFFF8, 0xEC37FFFF, 0xC3FFBFFF, 0x7FFFFFDF,
    0xFFFFFFFF, 0x001981FF, 0xF3FF2FF7, 0xEFFFFFFF,
    0xFFFFFFFF, 0x3E62FFFF, 0xF8000005, 0x003FCFFF,
    0x007E7E7E, 0xFFFF7F7F, 0xFFFFFFFF, 0xFFFF003F,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x03FF1EDF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFF000F, 0xFFFFF87F, 0x0FFFFFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFF3FFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x03FFFFFF, 0x00000000,
    0xA0F8007F, 0x5F7FFFFF, 0xFFFFFFDB, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFF80003, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFF0000, 0xFFFFFFFF,
    0xFFFCFFFF, 0xFFFFFFFF, 0x000000FF, 0x3FFF0000,
    0x03FF0000, 0xFFFF0000, 0xFFF7FFFF, 0xFFDF0F7F,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x1FFFFFFF,
    0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x3FFFFFFF, 0x7FFFFFFF, 0x1CFCFCFC, 0x30007F7F,
    0xFFFFEFFF, 0xB7FFFF7F, 0x3FFF3FFF, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x07FFFFFF,
    0xFFFFFF87, 0xFF8FFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x0FFF1FFF, 0x00000001, 0xFFFF0000, 0x1FFFFFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x1FFFFFFF, 0xFFFFFFFF, 0x0001FFFF, 0x0FFFFFFE,
    0xFFFFFFFF, 0xFFFF000F, 0xFFFF07FF, 0x003FFFFF,
    0xBFFFFFFF, 0xFFFFFFFF, 0x003FFF0F, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x3FFFFFFF, 0x000003FF, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFF00FF, 0xFFFFFFFF, 0x0000800F,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x007FFFFF, 0x003FFFFF, 0x000000FF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFD3F, 0x91BFFFFF, 0xFFBFFFFF, 0xFFFFFFFF,
    0x7FFFFFFF, 0x0000FF80, 0x00000000, 0xF837FFFF,
    0x8FFFFFFF, 0x83FFFFFF, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xF0FFFFFF, 0xFFFCFFFF, 0xFFFFFFFF,
    0xFEEF0001, 0x000FFFFF, 0x01FF00FF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x00000000, 0xFFFFFFFF, 0x007FF81F,
    0xFFFFFFFF, 0xFE3FFFFF, 0xFF3FFFFF, 0xFF07FFFF,
    0x1E03FFFF, 0x0000FE00, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0x000001FF, 0x00000000,
    0xFFFFFFFF, 0x0007FFFF, 0xFFFFFFFF, 0xFC07FFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x7FFFFFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFD, 0x00FFFFFF, 0xFFFC3F80, 0x0000FFFF,
    0xFFFFFFFC, 0xD987FFFF, 0xFFFF0003, 0x03FF01FF,
    0xFFFFFFF8, 0xFFC0107F, 0xFFFF000F, 0x0077FFFF,
    0xFFFFFFFC, 0x803FFFFF, 0xFFFF23FF, 0x001FFFFE,
    0xFFFBFFFF, 0x3F2C7FFF, 0x00000000, 0x00000000,
    0xBFFFBD7F, 0xFFFF03FF, 0x7FFFFFFF, 0x03FF0007,
    0xFFF99FEC, 0xA3EDFDFF, 0xE001399E, 0x0000000F,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0x5A06FFFF, 0x03FF00F2, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0x4F037FFF, 0x0FFFFFFE, 0x00000000,
    0xFFFFFFFF, 0x5807FFFF, 0x03FF001E, 0x00000000,
    0xFFFFFFFF, 0x0040D7FF, 0x000003FF, 0x00000000,
    0x03FFFFFF, 0xFFFF0043, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0xFFFFFFFF, 0xFFFFFFFF, 0x8007FFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0xFFFFFFFF, 0x01FFFFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x03FFFFFF, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x001F7FFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x0000000F, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0x00007FFF, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0x0000007F, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0x01FFFFFF, 0x7FFFFFFF, 0x0000C3FF,
    0x00000000, 0x00000000, 0xFFFF0000, 0x00203FFF,
    0xFFFFFFFF, 0xFF80FFFF, 0xFBFF003F, 0xE0FFFFFB,
    0x0000FFFF, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFF001F, 0x7FFFFFFF,
    0xFFF80000, 0x00000000, 0x00000000, 0x00000000,
    0x00000003, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x1FFF07FF,
    0x93FF01FF, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x003FFFFF,
    0xFFFFFFFF, 0xFFFFFE7F, 0xFFFFFFFF, 0x00003C5F,
    0xFFFFF018, 0xFFFFC3FF, 0xFFFFFFFF, 0x000001FF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x00000023, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0x007FFFFF, 0x0003FFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFDFFFFF, 0xFFFFFFFF,
    0xDFFFFFFF, 0xEBFFDE64, 0xFFFFFFEF, 0xFFFFFFFF,
    0xDFDFE7BF, 0x7BFFFFFF, 0xFFFDFC5F, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFF3F, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFCFFF, 0xFFFFFFFF,
    0x00000000, 0x07800000, 0x00000000, 0xFFDFE000,
    0x00000FEF, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x0000FF9F, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFEF, 0x0AF7FE96, 0xAA96EA84, 0x5EF7F796,
    0x0FFFFBFF, 0x0FFFFBEE, 0x00000000, 0x00030000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFF0FFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x000FFFFF, 0xFFFE7FFF, 0xFFFEFFFE, 0x003FFFFF,
    0xFFFF1FFF, 0xFFFF7FFF, 0xFFFFFFFF, 0xFFFF0FFF,
    0x07FFFFFF, 0x00000000, 0x00000000, 0xFFFFFFC0,
    0xFFFF0007, 0x07FFFFFF, 0x000301FF, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFBFFFFFF,
    0xFFFFFFFF, 0xFFFFFFEF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x0001FFFF, 0x000F1FFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x000FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x001FFFFF, 0x00000000,
    0xFFFF0FFF, 0xFFFFFFFF, 0x03FF00FF, 0xFFFFFFFF,
    0xFFFF00FF, 0x00003FFF, 0x00000000, 0x00000000,
    0x01FF0000, 0x00000000, 0x00000000, 0x00000000,
    0x0000001F, 0x00000000, 0x00000001, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x007FFFFF, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x001FFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x3FFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x00000003, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x3FFFFFFF, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000
  }
};
