/* DO NOT EDIT! GENERATED AUTOMATICALLY! */
/* Properties of Unicode characters.  */
/* Generated automatically by gen-uni-tables.c for Unicode 8.0.0.  */
#define header_0 16
#define header_2 9
#define header_3 127
#define header_4 15
static const
struct
  {
    int header[1];
    int level1[17];
    short level2[4 << 7];
    /*unsigned*/ int level3[53 << 4];
  }
u_property_bidi_left_to_right =
{
  { 17 },
  {
       18 * sizeof (int) / sizeof (short) +     0,
       18 * sizeof (int) / sizeof (short) +   128,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   384,
       18 * sizeof (int) / sizeof (short) +   256,
       18 * sizeof (int) / sizeof (short) +   256
  },
  {
       18 +   512 * sizeof (short) / sizeof (int) +     0,
       18 +   512 * sizeof (short) / sizeof (int) +    16,
       18 +   512 * sizeof (short) / sizeof (int) +    32,
       -1,
       18 +   512 * sizeof (short) / sizeof (int) +    48,
       18 +   512 * sizeof (short) / sizeof (int) +    64,
       18 +   512 * sizeof (short) / sizeof (int) +    80,
       18 +   512 * sizeof (short) / sizeof (int) +    96,
       18 +   512 * sizeof (short) / sizeof (int) +   112,
       18 +   512 * sizeof (short) / sizeof (int) +   128,
       18 +   512 * sizeof (short) / sizeof (int) +   144,
       18 +   512 * sizeof (short) / sizeof (int) +   160,
       18 +   512 * sizeof (short) / sizeof (int) +   176,
       18 +   512 * sizeof (short) / sizeof (int) +   192,
       18 +   512 * sizeof (short) / sizeof (int) +   208,
       18 +   512 * sizeof (short) / sizeof (int) +   224,
       18 +   512 * sizeof (short) / sizeof (int) +   240,
       18 +   512 * sizeof (short) / sizeof (int) +   256,
       18 +   512 * sizeof (short) / sizeof (int) +   272,
       18 +   512 * sizeof (short) / sizeof (int) +   288,
       18 +   512 * sizeof (short) / sizeof (int) +   304,
       18 +   512 * sizeof (short) / sizeof (int) +   320,
       18 +   512 * sizeof (short) / sizeof (int) +   336,
       18 +   512 * sizeof (short) / sizeof (int) +   352,
       18 +   512 * sizeof (short) / sizeof (int) +   368,
       18 +   512 * sizeof (short) / sizeof (int) +   384,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   416,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   432,
       18 +   512 * sizeof (short) / sizeof (int) +   448,
       18 +   512 * sizeof (short) / sizeof (int) +   464,
       18 +   512 * sizeof (short) / sizeof (int) +   480,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   496,
       -1,
       18 +   512 * sizeof (short) / sizeof (int) +   512,
       18 +   512 * sizeof (short) / sizeof (int) +   528,
       18 +   512 * sizeof (short) / sizeof (int) +   544,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       -1,
       -1,
       -1,
       -1,
       18 +   512 * sizeof (short) / sizeof (int) +   560,
       18 +   512 * sizeof (short) / sizeof (int) +   576,
       18 +   512 * sizeof (short) / sizeof (int) +   592,
       18 +   512 * sizeof (short) / sizeof (int) +   608,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   624,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   640,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   656,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   672,
       18 +   512 * sizeof (short) / sizeof (int) +   688,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   704,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   720,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   736,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   752,
       18 +   512 * sizeof (short) / sizeof (int) +   768,
       18 +   512 * sizeof (short) / sizeof (int) +   304,
       18 +   512 * sizeof (short) / sizeof (int) +   784,
       18 +   512 * sizeof (short) / sizeof (int) +   800,
       18 +   512 * sizeof (short) / sizeof (int) +   816,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   832,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   832,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       -1,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   400,
       18 +   512 * sizeof (short) / sizeof (int) +   832
  },
  {
    0x00000000, 0x00000000, 0x07FFFFFE, 0x07FFFFFE,
    0x00000000, 0x04200400, 0xFF7FFFFF, 0xFF7FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xF9FFFFFF, 0x00030003, 0x0000401F,
    0x00000000, 0x00000000, 0x00000000, 0xBFCF0000,
    0xFFFFFF4F, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFBFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFC07, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00001BFF, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFF8, 0xEBFFFFFF, 0xFF01DE01, 0xFFFFFFF3,
    0xFFFFFFFD, 0xEFFFFFFF, 0xFFFFDFE1, 0xF7F3FFF3,
    0xFFFFFFF9, 0xEFFFFFFF, 0xFFFDC679, 0xFFDCFFFF,
    0xFFFFFFF9, 0xEFFFFFFF, 0xFFFFDE41, 0xFFFDFFF3,
    0xFFFFFFFD, 0x6FFFFFFF, 0xFFBFDFE1, 0xFFFFFFF3,
    0xFFFFFFFB, 0xFFFFFFFF, 0xFFFFDFFE, 0xF807FFFF,
    0xFFFFFFFE, 0x3FFFFFFF, 0xFF9FC23E, 0x80FFFFF3,
    0xFFFFFFFD, 0xEFFFFFFF, 0xFFFFCFFF, 0xFFFFFFF3,
    0xFFFFFFFD, 0xFFFFFFFF, 0xFFFFDFE1, 0xFFFFFFF3,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFA3FBFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x780DFFFF, 0xFFFF807F, 0xFFFFFFFF,
    0xFFFFFFFF, 0xE40DFFFF, 0xFFFFC0FF, 0xFFFFFFFF,
    0xFCFFFFFF, 0xC15FFFFF, 0xFFFFFFFF, 0x8001FFFF,
    0x01001F20, 0xE0000000, 0xFFFFFFBF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x99021FFF, 0x3CFFFFFF, 0xFFE1FFFE,
    0xDFFFDF9B, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x1FFFFFFF, 0xFFFFFFFF,
    0xFC00FFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xE7FFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFE3FFFF, 0xFFE3FFFF, 0xFFF3FFFF, 0xFFF3FFFF,
    0xFFFFFFFF, 0xC04FFFFF, 0xD7F001BF, 0xFC00FFFF,
    0xFFFF8000, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFDFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xF1FBFE78, 0xFFFFFFCE, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x3FFFFFFF, 0x00000000,
    0xF67FFFFF, 0xFFFFFFFF, 0x80BFFFFF, 0x6007E01A,
    0xFFFFFFFF, 0x8000FFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFF0, 0xE82FFFFF, 0xFFFFFFFB, 0xFFF007FF,
    0xFFFFFFFC, 0xFFFFC4C3, 0xFFFFFFFF, 0xFFFC5CBF,
    0xFFFFFFFF, 0xFF300FFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x0008FFFF, 0xFCEFDE02,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x00000000, 0x0FC00000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x5FFFFFFF, 0x1FFF1FFC, 0x9FFF1FFF,
    0x00004000, 0x00000000, 0x00000000, 0x800E0000,
    0xFFFF8000, 0x80000000, 0x0000FFFF, 0xFFFE0000,
    0x3E2FFC84, 0xF3FFBD50, 0x0000C3E0, 0xFFFFFFFF,
    0x0000F1FF, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0xFFC00000, 0xFFFFFFFF, 0x07FFFFFF,
    0x00200000, 0x00000000, 0x00000000, 0xF8000000,
    0x00000000, 0xFFFFFF80, 0xFFFFF800, 0x00000000,
    0xF0000000, 0xFFFFFFFF, 0xFFFFFFFF, 0x000003FF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00001000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00300000,
    0x00C00000, 0x1C000000, 0xFFFC0200, 0xFFFF0FFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x01FC781F,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x7FFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000000,
    0x00000000, 0x00000000, 0xFFFFFFF8, 0xFFFFFFFF,
    0x04000000, 0x00000000, 0x00000000, 0xFFF00000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0xFFC00000, 0xF000FFFF,
    0x000000E0, 0x1F3EC3FE, 0xFFFFFFFF, 0xFFFFFFFF,
    0xE1FFFFFF, 0xFFFFFFFE, 0xFFFFFFFF, 0xF7FFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x00000000, 0xFFFFFFF0,
    0x9FFFFFFF, 0xFFFFFFFF, 0x0000FFFF, 0x8FFFFFFF,
    0xFFFFFFFF, 0x0001FFFF, 0xFFFF0FFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xF87FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x3FFFFFFF, 0x7FFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x00000000, 0x00000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x0000FFFF, 0x00000000, 0xFFFFFF80, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFF1FFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00007FFF,
    0x3FFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFCFFFF,
    0x00000000, 0xFFFFFFFC, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFEFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFF7BB, 0xFCFFF09F, 0xFFFFFFFF, 0xFF0FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFEF, 0xFFFC0000,
    0xFFFFFFFF, 0xFFFFC03F, 0xFFFC007F, 0xFFFFFFFF,
    0xFFFFFFF8, 0xEC37FFFF, 0xFFFFFFFF, 0xFFFFFFDF,
    0xFFFFFFFF, 0xFF9981FF, 0xFFFFEFF7, 0xEFFFFFFF,
    0xFFFFFFFF, 0x3E62FFFF, 0xFFFFFFFD, 0xFFBFCFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFDEDF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x1FFFFFFF, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000001, 0x07FFFFFE, 0x07FFFFFE, 0xFFFFFFC0,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00008080,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFD, 0xFFFFFFFF, 0x00000000, 0x00000000,
    0xF000E000, 0xFFFFFFFE, 0xFFFFFFFF, 0xDFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xF0000000,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xF83FFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFD, 0x00FFFFFF, 0x0003FF80, 0x7FFFFFC0,
    0xFFFFFFFC, 0xF987FFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFF8, 0xFFE0107F, 0xFFFFFFFF, 0xFFF7FFFF,
    0xFFFFFFFC, 0x803FFFFF, 0xFFFFE3FF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFF2C7FFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0x7FFFFFFF, 0xFFFFF807,
    0xFFFFFFFC, 0xEFFFFFFF, 0xFFFFFFFE, 0xFFE0E03F,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x7A07FFFF, 0xFFFFFFF2, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0x4FC3FFFF, 0xCFFFFFFE, 0xFFFFFFFF,
    0xFFFFFFFF, 0x5807FFFF, 0xFFFFFFFE, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFF40D7FF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x1FFFFFFF, 0xFFFFF043, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFE0FFFF,
    0xFFFFFFFF, 0xFF80FFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFF87FFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x9FFFFFFF, 0xFFFFFFF0, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0007FC7F,
    0xFFFFF018, 0xFFFFC3FF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00000000, 0x00000000, 0xFFFFFFC0, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00000000, 0x00000000, 0xFF800000, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xF7FFFFFF, 0xFFFFFFFF,
    0xFFDFFFFF, 0xFFFFFFFF, 0xFFFF7FFF, 0xFFFFFFFF,
    0xFFFFFDFF, 0xFFFFFFFF, 0x00003FF7, 0x00000000,
    0x00000000, 0x07800000, 0x00000000, 0xFFDFE000,
    0x07FFFFEF, 0xFFFF0001, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0xFF800060, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00000010, 0xF5080169, 0x5569157B, 0xA1080869,
    0xF0000400, 0xF0000411, 0xFFFFFFFF, 0xFFFCFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00000000, 0x0000F000, 0x00000000, 0x00000000,
    0xFFF00000, 0x00018000, 0x00010001, 0xFFC00000,
    0xFFFFE000, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFF3FF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x04000000,
    0x00000000, 0x00000010, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0x00000000, 0x00000000,
    0x00000000, 0x00000000, 0xFFFE0000, 0xFFF0E000,
    0x00000000, 0x00000000, 0x00000000, 0xFFF00000,
    0x00000000, 0x00000000, 0xFFE00000, 0xFFFFFFFF,
    0x0000F000, 0x00000000, 0xFC00FF00, 0x00000000,
    0x0000FF00, 0xFFFFC000, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFE00FFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFE0, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
    0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x3FFFFFFF
  }
};
